/*
      STELLATED PLATONIC SOLIDS for POV-Ray 2.2
      =========================================
     Constructed by Grant Hutchison [100047,144]  
Much data and encouragement from Tom Gettys [72730,2013]
Other data from "Polyhedron Models" by Magnus Wenninger

Declared below are several stellated forms of the simple
Platonic solids. The file has a slightly complicated structure,
in an effort to provide the maximum information in the smallest
file size.

Three objects are declared which can be used in POV-Ray scenes:

Stellated_Octahedron 
Stellated_Dodecahedron 
Stellated_Icosahedron 

(The cube and tetrahedron have no stellated forms.) 
The file is therefore divided into three sections, each dealing 
with one of these solids. The stellations come in several different 
forms, depending on the shape of their faces. The octahedron 
has a single stellation, the dodecahedron has three, and the 
icosahedron has 59 different stellations, 15 of which are given 
here.  Each type of face is declared as a union of different 
triangles, and is given the name of the stellated solid it will form. 
One of these faces is then chosen to be the face of the final 
stellation. For instance, in the DODECAHEDRA section, you will find 
the following declaration:

// ***********************************************************
// CHANGE FACE DECLARED BELOW TO CONSTRUCT A NEW DODECAHEDRON
#declare Dodecahedral_Face = object {Great_Dodecahedron_Face}
// ***********************************************************

Dodecahedral_Face is then "plugged in" to the standard dodecahedral
model to form the final Stellated_Dodecahedron. In this case, the
form generated will be the great dodecahedron. Similar declarations,
highlighted in stars, appear after the face declarations in the 
OCTAHEDRA and ICOSAHEDRA sections.
So to generate a particular solid, insert the name of its face object
into the relevant highlighted face declaration, as above. *Don't*
cross boundaries between solids - plugging a dodecahedral face into
the icosahedral stellation will have messy results!
Standard colour schemes are provided in each section: obviously, you
can play with these as you like. For reference, the face of the basic 
"parent" solid is also declared at the start of each section.

Each face is initially declared to scale with the parent solid, but
the resulting stellations can vary widely in size, making it difficult
to examine them all from a standard viewpoint. Therefore, each face
declaration includes a "scale" statement, which reduces the stellation
to a standard size: using this statement, all the stellations are
generated so that (when suitably orientated) they can rest with their 
points against the plane y, -1. The stellations with icosahedral
symmetry require a rotation before they will sit neatly in this way:
details are given at the start of each section. If you want to see
all the stellations to scale with each other, just "comment out" the
"scale" statement in the face declarations.
*/

#include "colors.inc"

/*
======================================================================
OCTAHEDRA

The octahedron has only one stellation, the Stella Octangula. It
fits neatly inside a unit cube when correctly scaled. Also included
for reference is the basic octahedron.
*/

#declare Basic_Octahedron_Face =
triangle {<0, 1.414213, -1>, <1.224745, -0.707107, -1>, <-1.224745, -0.707107, -1>}

#declare Stella_Octangula_Face =
triangle {<0, -2.828426, -1>, <2.449490, 1.414213, -1>, <-2.449490, 1.414213, -1>
  scale <0.577350, 0.577350, 0.577350>
}

// *********************************************************
// CHANGE FACE DECLARED BELOW TO CONSTRUCT A NEW OCTAHEDRON
#declare Octahedral_Face = object {Stella_Octangula_Face}
// *********************************************************

#declare Stellated_Octahedron = 
union {
  object {Octahedral_Face rotate <35.264390, 45, 0> pigment {color Blue}}
  object {Octahedral_Face rotate <35.264390, 135, 0> pigment {color White}}
  object {Octahedral_Face rotate <35.264390, 225, 0> pigment {color Blue}}
  object {Octahedral_Face rotate <35.264390, 315, 0> pigment {color White}}
  object {Octahedral_Face rotate 180*z rotate <-35.264390, 45, 0> pigment {color White}}
  object {Octahedral_Face rotate 180*z rotate <-35.264390, 135, 0> pigment {color Blue}}
  object {Octahedral_Face rotate 180*z rotate <-35.264390, 225, 0> pigment {color White}}
  object {Octahedral_Face rotate 180*z rotate <-35.264390, 315, 0> pigment {color Blue}}
}

/*
=========================================================================
DODECAHEDRA

The three stellations of the dodecahedron are declared below.
They are:

Small stellated dodecahedron*
Great dodecahedron*
Great stellated dodecahedron

The basic dodecahedron is also declared, for reference.
Stellations marked with stars have icosahedral symmetry. To see them
"standing" on three of their points, add "rotate 37.377368*x" to the 
final object before viewing.
*/

#declare Basic_Dodecahedron_Face =
union {
  triangle {<0, 0, -1>, <0.449028, 0.618034, -1>, <-0.449028, 0.618034, -1>}
  triangle {<0, 0, -1>, <0.449028, 0.618034, -1>, <-0.449028, 0.618034, -1> rotate 72*z}
  triangle {<0, 0, -1>, <0.449028, 0.618034, -1>, <-0.449028, 0.618034, -1> rotate 144*z}
  triangle {<0, 0, -1>, <0.449028, 0.618034, -1>, <-0.449028, 0.618034, -1> rotate 216*z}
  triangle {<0, 0, -1>, <0.449028, 0.618034, -1>, <-0.449028, 0.618034, -1> rotate 288*z}
}

#declare Small_Stellated_Dodecahedron_Face =
union {
  triangle {<0, 2, -1>, <0.449028, 0.618034, -1>, <-0.449028, 0.618034, -1>}
  triangle {<0, 2, -1>, <0.449028, 0.618034, -1>, <-0.449028, 0.618034, -1> rotate 72*z}
  triangle {<0, 2, -1>, <0.449028, 0.618034, -1>, <-0.449028, 0.618034, -1> rotate 144*z}
  triangle {<0, 2, -1>, <0.449028, 0.618034, -1>, <-0.449028, 0.618034, -1> rotate 216*z}
  triangle {<0, 2, -1>, <0.449028, 0.618034, -1>, <-0.449028, 0.618034, -1> rotate 288*z}
  scale <0.562777, 0.562777, 0.562777>
}

#declare Great_Dodecahedron_Face =
union {
  triangle {<0, 0, -1>, <1.175570, -1.618034, -1>, <-1.175570, -1.618034, -1>}
  triangle {<0, 0, -1>, <1.175570, -1.618034, -1>, <-1.175570, -1.618034, -1> rotate 72*z}
  triangle {<0, 0, -1>, <1.175570, -1.618034, -1>, <-1.175570, -1.618034, -1> rotate 144*z}
  triangle {<0, 0, -1>, <1.175570, -1.618034, -1>, <-1.175570, -1.618034, -1> rotate 216*z}
  triangle {<0, 0, -1>, <1.175570, -1.618034, -1>, <-1.175570, -1.618034, -1> rotate 288*z}
  scale <0.562777, 0.562777, 0.562777>
}

#declare Great_Stellated_Dodecahedron_Face =
union {
  triangle {<0, -5.236068, -1>, <1.175570, -1.618034, -1>, <-1.175570, -1.618034, -1>}
  triangle {<0, -5.236068, -1>, <1.175570, -1.618034, -1>, <-1.175570, -1.618034, -1> rotate 72*z}
  triangle {<0, -5.236068, -1>, <1.175570, -1.618034, -1>, <-1.175570, -1.618034, -1> rotate 144*z}
  triangle {<0, -5.236068, -1>, <1.175570, -1.618034, -1>, <-1.175570, -1.618034, -1> rotate 216*z}
  triangle {<0, -5.236068, -1>, <1.175570, -1.618034, -1>, <-1.175570, -1.618034, -1> rotate 288*z}
  scale <0.236068, 0.236068, 0.236068>
}

// ***********************************************************
// CHANGE FACE DECLARED BELOW TO CONSTRUCT A NEW DODECAHEDRON
#declare Dodecahedral_Face = object {Great_Dodecahedron_Face}
// ***********************************************************

#declare Stellated_Dodecahedron =
union {
  object {Dodecahedral_Face rotate <26.565051, 36, 0> pigment {color Blue}}
  object {Dodecahedral_Face rotate <26.565051, 108, 0> pigment {color Magenta}}
  object {Dodecahedral_Face rotate <26.565051, 180, 0> pigment {color Red}}
  object {Dodecahedral_Face rotate <26.565051, 252, 0> pigment {color Yellow}}
  object {Dodecahedral_Face rotate <26.565051, 324, 0> pigment {color Green}}
  object {Dodecahedral_Face rotate 180*z rotate <-26.565051, 0, 0> pigment {color Red}}
  object {Dodecahedral_Face rotate 180*z rotate <-26.565051, 72, 0> pigment {color Yellow}}
  object {Dodecahedral_Face rotate 180*z rotate <-26.565051, 144, 0> pigment {color Green}}
  object {Dodecahedral_Face rotate 180*z rotate <-26.565051, 216, 0> pigment {color Blue}}
  object {Dodecahedral_Face rotate 180*z rotate <-26.565051, 288, 0> pigment {color Magenta}}
  object {Dodecahedral_Face rotate -90*x pigment {color White}}
  object {Dodecahedral_Face rotate 90*x pigment {color White}}
}


/*
===================================================================
ICOSAHEDRA

There are fifty-nine stellations of the icosahedron. A selection
are declared below. They are:

Compound of five tetrahedra
Compound of ten tetrahedra
Compound of five octahedra
First stellation
Second stellation*
Third stellation
Fourth stellation
Sixth stellation*
Seventh stellation
Ninth stellation*
Tenth stellation
Fourteenth stellation
Fifteenth stellation
Great icosahedron*
Final stellation

The basic icosahedron is also declared, for reference.
Stellations marked with stars have icosahedral symmetry. To see them
"standing" on three of their points, add "rotate 37.377368*x" to the 
final object before viewing.
*/

#declare Basic_Icosahedron_Face =
triangle {<0, 0.763932, -1>, <0.661584, -0.381966, -1>, <-0.661584, -0.381966, -1>}

#declare Compound_Five_Tetrahedra_Face =
triangle {<1.070466, 2.618034, -1>, <1.732051, -2.236068, -1>, <-2.802517, -0.381966, -1>
//(alternative declaration)
//union {
//  triangle {<0, 0.763932, -1>, <-0.408881, 1.472136, -1>, <1.070466, 2.618034, -1>}
//  triangle {<1.070466, 2.618034, -1>, <1.323169, 0.763932, -1>, <0.408881, 1.472136, -1>}
//  triangle {<0, 0.763932, -1>, <-0.408881, 1.472136, -1>, <1.070466, 2.618034, -1> rotate 120*z}
//  triangle {<1.070466, 2.618034, -1>, <1.323169, 0.763932, -1>, <0.408881, 1.472136, -1> rotate 120*z}
//  triangle {<0, 0.763932, -1>, <-0.408881, 1.472136, -1>, <1.070466, 2.618034, -1> rotate 240*z}
//  triangle {<1.070466, 2.618034, -1>, <1.323169, 0.763932, -1>, <0.408881, 1.472136, -1> rotate 240*z}
  scale <0.419469, 0.419469, 0.419469>
}

#declare Compound_Ten_Tetrahedra_Face =
union {
  triangle {<1.070466, 2.618034, -1>, <1.732051, -2.236068, -1>, <-2.802517, -0.381966, -1>}
  triangle {<-1.070466, 2.618034, -1>, <-1.732051, -2.236068, -1>, <2.802517, -0.381966, -1>}
  scale <0.419469, 0.419469, 0.419469>
}

#declare Compound_Five_Octahedra_Face =
union {
  triangle {<0.535233, -1.309017, -1>, <0.866025, 1.118034, -1>, <-1.401258, 0.190983, -1>}
  triangle {<-0.535233, -1.309017, -1>, <-0.866025, 1.118034, -1>, <1.401258, 0.190983, -1>}
  scale <0.678716, 0.678716, 0.678716>
}

#declare First_Stellation_Face =
union {
  triangle {<-0.661584, -0.381966, -1>, <0.661584, -0.381966, -1>, <0, -0.894427, -1>}
  triangle {<-0.661584, -0.381966, -1>, <0.661584, -0.381966, -1>, <0, -0.894427, -1> rotate 120*z}
  triangle {<-0.661584, -0.381966, -1>, <0.661584, -0.381966, -1>, <0, -0.894427, -1> rotate 240*z}
  scale <0.937962, 0.937962, 0.937962>
}

#declare Second_Stellation_Face =
union {
  triangle {<-0.661584, -0.381966, -1>, <0.661584, -0.381966, -1>, <0, -5.236068, -1>}
  triangle {<-0.661584, -0.381966, -1>, <0.661584, -0.381966, -1>, <0, -5.236068, -1> rotate 120*z}
  triangle {<-0.661584, -0.381966, -1>, <0.661584, -0.381966, -1>, <0, -5.236068, -1> rotate 240*z}
  triangle {<1.070466, 2.618034, -1>, <1.732051, -2.236068, -1>, <-2.802517, -0.381966, -1>}
  triangle {<-1.070466, 2.618034, -1>, <-1.732051, -2.236068, -1>, <2.802517, -0.381966, -1>}
  scale <0.236068, 0.236068, 0.236068>
}

#declare Third_Stellation_Face =
union {
  triangle {<0, 0.763932, -1>, <1.070466, 2.618034, -1>, <-1.070466, 2.618034, -1>}
  triangle {<0, 0.763932, -1>, <1.070466, 2.618034, -1>, <-1.070466, 2.618034, -1> rotate 120*z}
  triangle {<0, 0.763932, -1>, <1.070466, 2.618034, -1>, <-1.070466, 2.618034, -1> rotate 240*z}
  scale <0.419469, 0.419469, 0.419469>
}

#declare Fourth_Stellation_Face =
union {
  triangle {<0.535233, -1.309017, -1>, <0.478727, -1.723607, -1>, <1.732051, -2.236068, -1>}
  triangle {<-0.535233, -1.309017, -1>, <-0.478727, -1.723607, -1>, <-1.732051, -2.236068, -1>}
  triangle {<0, 1.788854, -1>, <1.070466, 2.618034, -1>, <-1.070466, 2.618034, -1>}
  triangle {<0.535233, -1.309017, -1>, <0.478727, -1.723607, -1>, <1.732051, -2.236068, -1> rotate 120*z}
  triangle {<-0.535233, -1.309017, -1>, <-0.478727, -1.723607, -1>, <-1.732051, -2.236068, -1> rotate 120*z}
  triangle {<0, 1.788854, -1>, <1.070466, 2.618034, -1>, <-1.070466, 2.618034, -1> rotate 120*z}
  triangle {<0.535233, -1.309017, -1>, <0.478727, -1.723607, -1>, <1.732051, -2.236068, -1> rotate 240*z}
  triangle {<-0.535233, -1.309017, -1>, <-0.478727, -1.723607, -1>, <-1.732051, -2.236068, -1> rotate 240*z}
  triangle {<0, 1.788854, -1>, <1.070466, 2.618034, -1>, <-1.070466, 2.618034, -1> rotate 240*z}
  scale <0.419469, 0.419469, 0.419469>
}

#declare Sixth_Stellation_Face =
union {
  triangle {<-0.661584, -0.381966, -1>, <0.661584, -0.381966, -1>, <0, -5.236068, -1>}
  triangle {<-0.661584, -0.381966, -1>, <0.661584, -0.381966, -1>, <0, -5.236068, -1> rotate 120*z}
  triangle {<-0.661584, -0.381966, -1>, <0.661584, -0.381966, -1>, <0, -5.236068, -1> rotate 240*z}
  triangle {<0, 0.763932, -1>, <1.070466, 2.618034, -1>, <-1.070466, 2.618034, -1>}
  triangle {<0, 0.763932, -1>, <1.070466, 2.618034, -1>, <-1.070466, 2.618034, -1> rotate 120*z}
  triangle {<0, 0.763932, -1>, <1.070466, 2.618034, -1>, <-1.070466, 2.618034, -1> rotate 240*z}
  scale <0.236068, 0.236068, 0.236068>
}

#declare Seventh_Stellation_Face =
union {
  triangle {<0.661584, -0.381966, -1>, <1.732051, -2.236068, -1>, <0.535233, -1.309017, -1>}
  triangle {<-0.661584, -0.381966, -1>, <-1.732051, -2.236068, -1>, <-0.535233, -1.309017, -1>}
  triangle {<0.661584, -0.381966, -1>, <1.732051, -2.236068, -1>, <0.535233, -1.309017, -1> rotate 120*z}
  triangle {<-0.661584, -0.381966, -1>, <-1.732051, -2.236068, -1>, <-0.535233, -1.309017, -1> rotate 120*z}
  triangle {<0.661584, -0.381966, -1>, <1.732051, -2.236068, -1>, <0.535233, -1.309017, -1> rotate 240*z}
  triangle {<-0.661584, -0.381966, -1>, <-1.732051, -2.236068, -1>, <-0.535233, -1.309017, -1> rotate 240*z}
  scale <0.419469, 0.419469, 0.419469>
}

#declare Ninth_Stellation_Face =
union {
  triangle {<-0.661584, -0.381966, -1>, <0.661584, -0.381966, -1>, <0, -5.236068, -1>}
  triangle {<-0.661584, -0.381966, -1>, <0.661584, -0.381966, -1>, <0, -5.236068, -1> rotate 120*z}
  triangle {<-0.661584, -0.381966, -1>, <0.661584, -0.381966, -1>, <0, -5.236068, -1> rotate 240*z}
  scale <0.236068, 0.236068, 0.236068>
}

#declare Tenth_Stellation_Face =
union {
  triangle {<-0.535233, -1.309017, -1>, <-0.478727, -1.723607, -1>, <-1.732051, -2.236068, -1>}
  triangle {<-0.408881, 1.472136, -1>, <0, 1.788854, -1>, <-1.070466, 2.618034, -1>}
  triangle {<0.408881, 1.472136, -1>, <0.866025, 1.118034, -1>, <1.070466, 2.618034, -1>}
  triangle {<0, -1.527864, -1>, <0.478727, -1.723607, -1>, <0.535233, -1.309017, -1>}
  triangle {<-0.535233, -1.309017, -1>, <-0.478727, -1.723607, -1>, <-1.732051, -2.236068, -1> rotate 120*z}
  triangle {<-0.408881, 1.472136, -1>, <0, 1.788854, -1>, <-1.070466, 2.618034, -1> rotate 120*z}
  triangle {<0.408881, 1.472136, -1>, <0.866025, 1.118034, -1>, <1.070466, 2.618034, -1> rotate 120*z}
  triangle {<0, -1.527864, -1>, <0.478727, -1.723607, -1>, <0.535233, -1.309017, -1> rotate 120*z}
  triangle {<-0.535233, -1.309017, -1>, <-0.478727, -1.723607, -1>, <-1.732051, -2.236068, -1> rotate 240*z}
  triangle {<-0.408881, 1.472136, -1>, <0, 1.788854, -1>, <-1.070466, 2.618034, -1> rotate 240*z}
  triangle {<0.408881, 1.472136, -1>, <0.866025, 1.118034, -1>, <1.070466, 2.618034, -1> rotate 240*z}
  triangle {<0, -1.527864, -1>, <0.478727, -1.723607, -1>, <0.535233, -1.309017, -1> rotate 240*z}
  scale <0.419469, 0.419469, 0.419469>
}

#declare Fourteenth_Stellation_Face =
union {
  triangle {<-0.535233, -1.309017, -1>, <1.732051, -2.236068, -1>, <0, -0.894427, -1>}
  triangle {<2.802517, -0.381966, -1>, <1.732051, -2.236068, -1>, <1.401258, 0.190983, -1>}
  triangle {<-0.535233, -1.309017, -1>, <1.732051, -2.236068, -1>, <0, -0.894427, -1> rotate 120*z}
  triangle {<2.802517, -0.381966, -1>, <1.732051, -2.236068, -1>, <1.401258, 0.190983, -1> rotate 120*z}
  triangle {<-0.535233, -1.309017, -1>, <1.732051, -2.236068, -1>, <0, -0.894427, -1> rotate 240*z}
  triangle {<2.802517, -0.381966, -1>, <1.732051, -2.236068, -1>, <1.401258, 0.190983, -1> rotate 240*z}
  scale <0.419469, 0.419469, 0.419469>
}

#declare Fifteenth_Stellation_Face =
union {
  triangle {<0, 0.763932, -1>, <0.866025, 1.118034, -1>, <1.070466, 2.618034, -1>}
  triangle {<0, 0.763932, -1>, <0.408881, 1.472136, -1>, <-1.070466, 2.618034, -1>}
  triangle {<0, 0.763932, -1>, <-0.866025, 1.118034, -1>, <-0.408881, 1.472136, -1>}
  triangle {<-0.866025, 1.118034, -1>, <-1.070466, 2.618034, -1>, <-1.323169, 0.763932, -1>}
  triangle {<0, 0.763932, -1>, <0.866025, 1.118034, -1>, <1.070466, 2.618034, -1> rotate 120*z}
  triangle {<0, 0.763932, -1>, <0.408881, 1.472136, -1>, <-1.070466, 2.618034, -1> rotate 120*z}
  triangle {<0, 0.763932, -1>, <-0.866025, 1.118034, -1>, <-0.408881, 1.472136, -1> rotate 120*z}
  triangle {<-0.866025, 1.118034, -1>, <-1.070466, 2.618034, -1>, <-1.323169, 0.763932, -1> rotate 120*z}
  triangle {<0, 0.763932, -1>, <0.866025, 1.118034, -1>, <1.070466, 2.618034, -1> rotate 240*z}
  triangle {<0, 0.763932, -1>, <0.408881, 1.472136, -1>, <-1.070466, 2.618034, -1> rotate 240*z}
  triangle {<0, 0.763932, -1>, <-0.866025, 1.118034, -1>, <-0.408881, 1.472136, -1> rotate 240*z}
  triangle {<-0.866025, 1.118034, -1>, <-1.070466, 2.618034, -1>, <-1.323169, 0.763932, -1> rotate 240*z}
  scale <0.419469, 0.419469, 0.419469>
}

#declare Great_Icosahedron_Face =
triangle {<4.534568, 2.618034, -1>, <-4.534568, 2.618034, -1>, <0, -5.236068, -1>
  scale <0.236068, 0.236068, 0.236068>
}

#declare Final_Stellation_Face =
union {
  triangle {<1.070466, 2.618034, -1>, <-1.070466, 2.618034, -1>, <0, 10.472136, -1>}
  triangle {<4.534568, 2.618034, -1>, <10.139602, 2.618034, -1>, <2.802517, -0.381966, -1>}
  triangle {<-4.534568, 2.618034, -1>, <-10.139602, 2.618034, -1>, <-2.802517, -0.381966, -1>}
  triangle {<1.070466, 2.618034, -1>, <-1.070466, 2.618034, -1>, <0, 10.472136, -1> rotate 120*z}
  triangle {<4.534568, 2.618034, -1>, <10.139602, 2.618034, -1>, <2.802517, -0.381966, -1> rotate 120*z}
  triangle {<-4.534568, 2.618034, -1>, <-10.139602, 2.618034, -1>, <-2.802517, -0.381966, -1> rotate 120*z}
  triangle {<1.070466, 2.618034, -1>, <-1.070466, 2.618034, -1>, <0, 10.472136, -1> rotate 240*z}
  triangle {<4.534568, 2.618034, -1>, <10.139602, 2.618034, -1>, <2.802517, -0.381966, -1> rotate 240*z}
  triangle {<-4.534568, 2.618034, -1>, <-10.139602, 2.618034, -1>, <-2.802517, -0.381966, -1> rotate 240*z}
  scale <0.100898, 0.100898, 0.100898>
}

// **********************************************************
// CHANGE FACE DECLARED BELOW TO CONSTRUCT A NEW ICOSAHEDRON
#declare Icosahedral_Face = object {Final_Stellation_Face}
// **********************************************************

#declare Stellated_Icosahedron =
union {
  object {Icosahedral_Face rotate <52.622632, 0, 0> pigment {color White}}
  object {Icosahedral_Face rotate <52.622632, 72, 0> pigment {color Blue}}
  object {Icosahedral_Face rotate <52.622632, 144, 0> pigment {color Magenta}}
  object {Icosahedral_Face rotate <52.622632, 216, 0> pigment {color Red}}
  object {Icosahedral_Face rotate <52.622632, 288, 0> pigment {color Green}}
  object {Icosahedral_Face rotate 180*z rotate <10.812317, 0, 0> pigment {color Red}}
  object {Icosahedral_Face rotate 180*z rotate <10.812317, 72, 0> pigment {color Green}}
  object {Icosahedral_Face rotate 180*z rotate <10.812317, 144, 0> pigment {color White}}
  object {Icosahedral_Face rotate 180*z rotate <10.812317, 216, 0> pigment {color Blue}}
  object {Icosahedral_Face rotate 180*z rotate <10.812317, 288, 0> pigment {color Magenta}}
  object {Icosahedral_Face rotate <-10.812317, 36, 0> pigment {color Magenta}}
  object {Icosahedral_Face rotate <-10.812317, 108, 0> pigment {color Red}}
  object {Icosahedral_Face rotate <-10.812317, 180, 0> pigment {color Green}}
  object {Icosahedral_Face rotate <-10.812317, 252, 0> pigment {color White}}
  object {Icosahedral_Face rotate <-10.812317, 324, 0> pigment {color Blue}}
  object {Icosahedral_Face rotate 180*z rotate <-52.622632, 36, 0> pigment {color White}}
  object {Icosahedral_Face rotate 180*z rotate <-52.622632, 108, 0> pigment {color Blue}}
  object {Icosahedral_Face rotate 180*z rotate <-52.622632, 180, 0> pigment {color Magenta}}
  object {Icosahedral_Face rotate 180*z rotate <-52.622632, 252, 0> pigment {color Red}}
  object {Icosahedral_Face rotate 180*z rotate <-52.622632, 324, 0> pigment {color Green}}
}


// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// ADD A SCENE     
// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

global_settings { assumed_gamma 2.2 }

camera {
   location < 5.0, 5.0, -15.0 >
   direction < 0.0, 0.0, 5.0 >
   up < 0.0, 1.0, 0.0 >
   right < 1.33333, 0.0, 0.0 > 
   look_at < 0.0, 0.0, 0.0 >
}

light_source { < 100.0, 100.0, -100.0 > colour rgb 1 }

light_source { < -100.0, 0.0, -50.0 > colour rgb 0.5 }

object { Stellated_Icosahedron }
